@@ -96,26 +96,14 @@ fn test_debug_query() -> Result<()> {
 }
 
 #[test]
-fn test_invalid_sg_config() -> Result<()> {
-  let dir = create_test_files([("invalid.yml", "invalid")])?;
-  Command::cargo_bin("ast-grep")?
-    .current_dir(dir.path())
-    .args(["-p", "alert($A)", "-c", "invalid.yml"])
-    .assert()
-    .failure()
-    .stderr(contains("Cannot parse configuration"));
-  Ok(())
-}
-
-#[test]
-fn test_unfound_sg_config() -> Result<()> {
+fn test_unsupport_config_arg() -> Result<()> {
   let dir = create_test_files([])?;
   Command::cargo_bin("ast-grep")?
     .current_dir(dir.path())
     .args(["-p", "alert($A)", "-c", "not-found.yml"])
     .assert()
     .failure()
-    .stderr(contains("Cannot read configuration"));
+    .stderr(contains("unexpected argument"));
   Ok(())
 }
 
